#ifndef CAMLOAD_LIB_ENUMS_H
#define CAMLOAD_LIB_ENUMS_H

/*	// Disabled #pragma once , the header needs to be included multiple times
#ifdef _MSC_VER
#pragma once
#endif
*/

/////////////////////////////////////////////////////////////////////////////
// cross-platform defines

#if defined(__cplusplus_cli) && defined(P1_CAMLOAD_DOTNET_ENUM)
#define P1_PUBLIC_ENUM      public enum class
#define P1_ENUM_TYPEDEF(e)
#else
#define P1_PUBLIC_ENUM      enum
#define P1_ENUM_TYPEDEF(e)  typedef enum e e;
#endif

/////////////////////////////////////////////////////////////////////////////

#if (defined(__cplusplus) || defined(__cplusplus_cli)) && !defined(__OBJC__)

namespace P1 {
namespace CamLoad {

#if defined P1_CAMLOAD_DOTNET_ENUM
namespace Enums {
#endif // P1_CAMLOAD_DOTNET_ENUM

#endif		
	
/////////////////////////////////////////////////////////////////////////////	
	
	//-------------------------
	// CamLoad Event 
	//-------------------------
	P1_PUBLIC_ENUM EnumCamLoadEventType
	{
		CAMLOAD_EVENT_EMPTY_EVENT				= 0, // Empty initialized event, ignore
		CAMLOAD_EVENT_DEVICE_CONNECTED			= 1, // a device has been connected
		CAMLOAD_EVENT_DEVICE_DISCONNECTED		= 2, // a device has been disconnected
		CAMLOAD_EVENT_UPDATE_PROGRESS			= 3, // change in progress for update event
		CAMLOAD_EVENT_UPDATE_SUCCESSFUL			= 4, // firmware update finished successfully
		CAMLOAD_EVENT_UPDATE_FAILURE			= 5, // firmware update finished with an error	
		CAMLOAD_EVENT_UPDATE_STOPPED			= 6, // firmware update stopped
		CAMLOAD_EVENT_UPDATE_STATUS_UPDATED		= 7, // firmware update status has changed (new status mesage)
		CAMLOAD_EVENT_UPDATE_START_FAILED		= 8, // failed to initialize update process
		CAMLOAD_EVENT_UPDATE_STARTED			= 9, // update process has been started
		CAMLOAD_EVENT_RECONNECT_NEEDED			= 10, // 
		CAMLOAD_EVENT_DEVICE_MODEL_DATA_CHANGED = 11  // One or more of model properties have changed.
	};
	P1_ENUM_TYPEDEF(EnumCamLoadEventType);	
	
	/*
	//-------------------------
	// Firmware Types
	//-------------------------
	P1_PUBLIC_ENUM EnumCamLoadFirmwareType
	{
		CAMLOAD_FIRMWARE_CAMBODY			= 1, // the firmware used by the camera body
		CAMLOAD_FIRMWARE_VERTGRIP			= 2, // the firmware used by the vertical grip
		//CAMLOAD_FIRMWARE_LENS				= 3, // the firmware used by the lens (not possible atm)
	};

	P1_ENUM_TYPEDEF(EnumCamLoadFirmwareType);
	
	*/
	
	
	//-------------------------
	// Device Properties
	//-------------------------
	/* 
	// Not used anywhere
	P1_PUBLIC_ENUM EnumCamLoadDeviceManufacturer
	{
		CAMLOAD_DEVICE_MANUFACTURER_NONE		= 0, // if the device doesn't exist
		CAMLOAD_DEVICE_MANUFACTURER_MAMIYA		= 1, // based on the Vendor ID of the USB device
		CAMLOAD_DEVICE_MANUFACTURER_PHASE_ONE	= 2  // based on the Vid and Pid (lookup table in SupportedDevices.cpp
	};
	P1_ENUM_TYPEDEF(EnumCamLoadDeviceManufacturer);
	*/

	P1_PUBLIC_ENUM EnumCamLoadDeviceType
	{
		CAMLOAD_DEVICE_TYPE_NONE					= 0,	// if the requested device doesnt exist
		
		//devices (related to what protocol is used)
		CAMLOAD_DEVICE_TYPE_VERTGRIP_EXTERNALS,		// a vertical grip in camera house update mode
		CAMLOAD_DEVICE_TYPE_VERTGRIP_DIRECT,			// a vertical grip in v-grip update mode
		CAMLOAD_DEVICE_TYPE_INDUSTRIAL_CAMERA,		// a industrial camera (iXR/iXA) in DFU mode
		CAMLOAD_DEVICE_TYPE_DIGITAL_BACK,					// a digital back
		
		//models - camera bodies
		CAMLOAD_MODEL_TYPE_CAMBODY_GENERIC			= 1000,
		// Because of the serial number checking requirement
		// we need a new device type of 645DFUNKNKONW will be returned
		// initially with requirement of servial number update (we cannot
		// query it from the V-Grip) after correct serial number is given
		// we can go with 645DF or 645DFPLUS
		CAMLOAD_MODEL_TYPE_CAMBODY_645DFGENERIC,
		CAMLOAD_MODEL_TYPE_CAMBODY_645DF,
		CAMLOAD_MODEL_TYPE_CAMBODY_645DFPLUS,
		CAMLOAD_MODEL_TYPE_CAMBODY_iX,
		CAMLOAD_MODEL_TYPE_CAMBODY_ENDMARKER,				// use the endmarkers to find if it's within range of types (eg all CAMBODY types)
		
		//models - lens
		CAMLOAD_MODEL_TYPE_LENS_GENERIC				= 2000,
		CAMLOAD_MODEL_TYPE_LENS_ENDMARKER,
		
		//models - digital backs
		CAMLOAD_MODEL_TYPE_DB_GENERIC				= 3000,
		CAMLOAD_MODEL_TYPE_DB_PBACK,
		CAMLOAD_MODEL_TYPE_DB_LEGACY,
		CAMLOAD_MODEL_TYPE_DB_IQBACK,
        CAMLOAD_MODEL_TYPE_DB_CREDO,
		CAMLOAD_MODEL_TYPE_DB_ENDMARKER,
	};
	P1_ENUM_TYPEDEF(EnumCamLoadDeviceType);
	

/////////////////////////////////////////////////////////////////////////////

#if (defined(__cplusplus) || defined(__cplusplus_cli)) && !defined(__OBJC__)

#if defined P1_CAMLOAD_DOTNET_ENUM
} // ns Enums
#endif // P1_CAMLOAD_DOTNET_ENUM

} //namespace CamLoad
} //namespace P1
#endif

/////////////////////////////////////////////////////////////////////////////

// cleanup local defines
#undef P1_PUBLIC_ENUM
#undef P1_ENUM_TYPEDEF

/////////////////////////////////////////////////////////////////////////////

#endif //CAMLOAD_LIB_ENUMS_H
